==> _private_core_network-1.0.14.tar.gz: lib/network_resources/repository/homelido_repo.dart <==
import 'package:_private_core/_private_core.dart';
import '../resources.dart';

class HomelidoRepo {
  HomelidoRepo._();

  static HomelidoRepo? _instance;

  factory HomelidoRepo() {
    _instance ??= HomelidoRepo._();
    return _instance!;
  }

  final AppApiImp _api = AppApiImp();

  Future<IdResult?> createHomlidoMeeting(
      {userUniqueId, meetingDatetime, propertyId}) async {
    NetworkResponse response = await _api.createHomlidoMeeting({
      'userUniqueId': userUniqueId,
      'meetingDatetime': meetingDatetime,
      'propertyId': propertyId
    });
    return response.data;
  }

  Future<HomelidoMeeting?> getHomelidoMeetingDetails(
      {meetingId, languageCode}) async {
    NetworkResponse response = await _api.getHomelidoMeetingDetails({
      'meetingId': meetingId,
      'languageCode': languageCode ?? appPrefs.languageCode,
    });
    return response.data;
  }

  Future<bool> answerToHomelidoVisitRequest(
      {status, meetingDatetime, meetingId}) async {
    NetworkResponse response = await _api.answerToHomelidoVisitRequest({
      'status': status,
      'meetingDatetime': meetingDatetime,
      'meetingId': meetingId
    });
    return response.data ?? false;
  }

  Future<bool> updateHomelidoMeeting(
      {status, meetingDatetime, meetingId}) async {
    NetworkResponse response = await _api.updateHomelidoMeeting({
      'status': status,
      'meetingDatetime': meetingDatetime,
      'meetingId': meetingId
    });
    return response.data ?? false;
  }
}

==> _private_core_network-1.1.5.tar.gz: lib/network_resources/repository/homelido_repo.dart <==
import 'package:_private_core/_private_core.dart';
import '../resources.dart';

class HomelidoRepo {
  HomelidoRepo._();

  static HomelidoRepo? _instance;

  factory HomelidoRepo() {
    _instance ??= HomelidoRepo._();
    return _instance!;
  }

  final AppApiImp _api = AppApiImp();

  Future<IdResult?> createHomelidoMeeting(
      {userUniqueId, meetingDatetime, propertyId}) async {
    NetworkResponse response = await _api.createHomelidoMeeting({
      'userUniqueId': userUniqueId,
      'meetingDatetime': meetingDatetime,
      'propertyId': propertyId
    });
    return response.data;
  }

  Future<HomelidoMeeting?> getHomelidoMeetingDetails(
      {meetingId, languageCode}) async {
    NetworkResponse response = await _api.getHomelidoMeetingDetails({
      'meetingId': meetingId,
      'languageCode': languageCode ?? appPrefs.languageCode,
    });
    return response.data;
  }

  Future<bool> answerToHomelidoVisitRequest(
      {status, meetingDatetime, meetingId}) async {
    NetworkResponse response = await _api.answerToHomelidoVisitRequest({
      'status': status,
      'meetingDatetime': meetingDatetime,
      'meetingId': meetingId
    });
    return response.data ?? false;
  }

  Future<bool> updateHomelidoMeeting(
      {status, meetingDatetime, meetingId}) async {
    NetworkResponse response = await _api.updateHomelidoMeeting({
      'status': status,
      'meetingDatetime': meetingDatetime,
      'meetingId': meetingId
    });
    return response.data ?? false;
  }
}
